
import sys
if sys.version_info >= (3, 8):
    from typing import Protocol
else:
    from typing_extensions import Protocol

import java.io
import java.lang
import java.util
import jpype
import jneqsim.neqsim.processSimulation.processEquipment
import jneqsim.neqsim.thermo.system
import typing



class EnergyStream(java.io.Serializable, java.lang.Cloneable):
    def __init__(self): ...
    def clone(self) -> 'EnergyStream': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getDuty(self) -> float: ...
    def hashCode(self) -> int: ...
    def setDuty(self, double: float) -> None: ...

class StreamInterface(jneqsim.neqsim.processSimulation.processEquipment.ProcessEquipmentInterface):
    def CCB(self, string: str) -> float: ...
    def CCT(self, string: str) -> float: ...
    def GCV(self) -> float: ...
    def LCV(self) -> float: ...
    def TVP(self, double: float, string: str) -> float: ...
    def clone(self) -> 'StreamInterface': ...
    def equals(self, object: typing.Any) -> bool: ...
    def flashStream(self) -> None: ...
    def getFlowRate(self, string: str) -> float: ...
    def getHydrateEquilibriumTemperature(self) -> float: ...
    def getMolarRate(self) -> float: ...
    @typing.overload
    def getPressure(self) -> float: ...
    @typing.overload
    def getPressure(self, string: str) -> float: ...
    @typing.overload
    def getTemperature(self) -> float: ...
    @typing.overload
    def getTemperature(self, string: str) -> float: ...
    def getThermoSystem(self) -> jneqsim.neqsim.thermo.system.SystemInterface: ...
    def hashCode(self) -> int: ...
    def runTPflash(self) -> None: ...
    def setEmptyThermoSystem(self, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface) -> None: ...
    def setFlowRate(self, double: float, string: str) -> None: ...
    def setFluid(self, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface) -> None: ...
    def setName(self, string: str) -> None: ...
    @typing.overload
    def setPressure(self, double: float) -> None: ...
    @typing.overload
    def setPressure(self, double: float, string: str) -> None: ...
    def setTemperature(self, double: float, string: str) -> None: ...
    def setThermoSystem(self, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface) -> None: ...
    def setThermoSystemFromPhase(self, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface, string: str) -> None: ...

class VirtualStream(jneqsim.neqsim.processSimulation.processEquipment.ProcessEquipmentBaseClass):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, streamInterface: StreamInterface): ...
    def getOutStream(self) -> StreamInterface: ...
    @typing.overload
    def run(self) -> None: ...
    @typing.overload
    def run(self, uUID: java.util.UUID) -> None: ...
    def setComposition(self, doubleArray: typing.Union[typing.List[float], jpype.JArray], string: str) -> None: ...
    def setFlowRate(self, double: float, string: str) -> None: ...
    @typing.overload
    def setPressure(self, double: float) -> None: ...
    @typing.overload
    def setPressure(self, double: float, string: str) -> None: ...
    def setReferenceStream(self, streamInterface: StreamInterface) -> None: ...
    def setTemperature(self, double: float, string: str) -> None: ...
    def solved(self) -> bool: ...

class Stream(jneqsim.neqsim.processSimulation.processEquipment.ProcessEquipmentBaseClass, StreamInterface, java.lang.Cloneable):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, streamInterface: StreamInterface): ...
    @typing.overload
    def __init__(self, string: str, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface): ...
    @typing.overload
    def __init__(self, streamInterface: StreamInterface): ...
    @typing.overload
    def __init__(self, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface): ...
    def CCB(self, string: str) -> float: ...
    def CCT(self, string: str) -> float: ...
    def GCV(self) -> float: ...
    def LCV(self) -> float: ...
    def TVP(self, double: float, string: str) -> float: ...
    def clone(self) -> 'Stream': ...
    def displayResult(self) -> None: ...
    def flashStream(self) -> None: ...
    def getFluid(self) -> jneqsim.neqsim.thermo.system.SystemInterface: ...
    def getGasQuality(self) -> float: ...
    def getHydrateEquilibriumTemperature(self) -> float: ...
    def getMolarRate(self) -> float: ...
    @typing.overload
    def getPressure(self) -> float: ...
    @typing.overload
    def getPressure(self, string: str) -> float: ...
    @typing.overload
    def getProperty(self, string: str) -> typing.Any: ...
    @typing.overload
    def getProperty(self, string: str, string2: str, string3: str, string4: str) -> typing.Any: ...
    def getResultTable(self) -> typing.MutableSequence[typing.MutableSequence[str]]: ...
    def getSolidFormationTemperature(self, string: str) -> float: ...
    @typing.overload
    def getTemperature(self) -> float: ...
    @typing.overload
    def getTemperature(self, string: str) -> float: ...
    def getThermoSystem(self) -> jneqsim.neqsim.thermo.system.SystemInterface: ...
    def needRecalculation(self) -> bool: ...
    def phaseEnvelope(self) -> None: ...
    def reportResults(self) -> typing.MutableSequence[typing.MutableSequence[str]]: ...
    @typing.overload
    def run(self) -> None: ...
    @typing.overload
    def run(self, uUID: java.util.UUID) -> None: ...
    def runController(self, double: float, uUID: java.util.UUID) -> None: ...
    def runTPflash(self) -> None: ...
    @typing.overload
    def runTransient(self, double: float) -> None: ...
    @typing.overload
    def runTransient(self, double: float, uUID: java.util.UUID) -> None: ...
    def setEmptyThermoSystem(self, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface) -> None: ...
    def setFlowRate(self, double: float, string: str) -> None: ...
    def setFluid(self, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface) -> None: ...
    def setGasQuality(self, double: float) -> None: ...
    @typing.overload
    def setPressure(self, double: float) -> None: ...
    @typing.overload
    def setPressure(self, double: float, string: str) -> None: ...
    def setStream(self, streamInterface: StreamInterface) -> None: ...
    def setTemperature(self, double: float, string: str) -> None: ...
    def setThermoSystem(self, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface) -> None: ...
    def setThermoSystemFromPhase(self, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface, string: str) -> None: ...

class EquilibriumStream(Stream):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface): ...
    @typing.overload
    def __init__(self, streamInterface: StreamInterface): ...
    @typing.overload
    def __init__(self, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface): ...
    def clone(self) -> 'EquilibriumStream': ...
    @typing.overload
    def run(self) -> None: ...
    @typing.overload
    def run(self, uUID: java.util.UUID) -> None: ...

class IronIonSaturationStream(Stream):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, streamInterface: StreamInterface): ...
    @typing.overload
    def __init__(self, string: str, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface): ...
    @typing.overload
    def __init__(self, streamInterface: StreamInterface): ...
    @typing.overload
    def __init__(self, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface): ...
    def clone(self) -> 'IronIonSaturationStream': ...
    def displayResult(self) -> None: ...
    @typing.overload
    def run(self) -> None: ...
    @typing.overload
    def run(self, uUID: java.util.UUID) -> None: ...

class NeqStream(Stream):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, streamInterface: StreamInterface): ...
    @typing.overload
    def __init__(self, string: str, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface): ...
    @typing.overload
    def __init__(self, streamInterface: StreamInterface): ...
    @typing.overload
    def __init__(self, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface): ...
    def clone(self) -> 'NeqStream': ...
    @typing.overload
    def run(self) -> None: ...
    @typing.overload
    def run(self, uUID: java.util.UUID) -> None: ...

class ScalePotentialCheckStream(Stream):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, streamInterface: StreamInterface): ...
    @typing.overload
    def __init__(self, string: str, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface): ...
    @typing.overload
    def __init__(self, streamInterface: StreamInterface): ...
    @typing.overload
    def __init__(self, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface): ...
    def clone(self) -> 'ScalePotentialCheckStream': ...
    def displayResult(self) -> None: ...
    @typing.overload
    def run(self) -> None: ...
    @typing.overload
    def run(self, uUID: java.util.UUID) -> None: ...


class __module_protocol__(Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("jneqsim.neqsim.processSimulation.processEquipment.stream")``.

    EnergyStream: typing.Type[EnergyStream]
    EquilibriumStream: typing.Type[EquilibriumStream]
    IronIonSaturationStream: typing.Type[IronIonSaturationStream]
    NeqStream: typing.Type[NeqStream]
    ScalePotentialCheckStream: typing.Type[ScalePotentialCheckStream]
    Stream: typing.Type[Stream]
    StreamInterface: typing.Type[StreamInterface]
    VirtualStream: typing.Type[VirtualStream]
